@@ -474,7 +474,10 @@ function install_setup_get_templates() {
 		'APC_InfraStruXure_InRow_CRAC.xml.gz',
 		'APC_InfraStruXure_PDU.xml.gz',
 		'Apache_Webserver.xml.gz',
+		'ArubaOS_switch.xml.gz',
+		'Aruba_OSCX_switch_6x00.xml.gz',
 		'Aruba_Instant_AP_Cluster.xml.gz',
+		'Aruba_Wireless_Controller.xml.gz',
 		'BayTech_PDU.xml.gz',
 		'Cacti_Stats.xml.gz',
 		'Cisco_Router.xml.gz',
@@ -482,6 +485,7 @@ function install_setup_get_templates() {
 		'ESXi_Device.xml.gz',
 		'Fortigate.xml.gz',
 		'Generic_SNMP_Device.xml.gz',
+		'HPE_iLO.xml.gz',
 		'Local_Linux_Machine.xml.gz',
 		'MikroTik_Device.xml.gz',
 		'MikroTik_Switch_SWOS.xml.gz',
