@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDtool-based Graphing Solution                     |
+ | Cacti: The Complete RRDTool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -22,47 +22,20 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_1_1_36() {
-	// Repair locales
-	$def_locale = repair_locale(read_config_option('i18n_default_language'));
-	set_config_option('i18n_default_language', $def_locale);
+function upgrade_to_1_2_21() {
+	global $config;
 
-	$users_to_update_results = db_install_fetch_assoc('SELECT *
-		FROM settings_user
-		WHERE name="user_language"');
-	$users_to_update = $users_to_update_results['data'];
-
-	if (cacti_sizeof($users_to_update)) {
-		foreach($users_to_update as $user) {
-			if (strpos($user['value'], '-') === false) {
-				$locale = repair_locale($user['value']);
-
-				db_install_execute('UPDATE settings_user
-					SET value = ?
-					WHERE user_id = ?
-					AND name = ?',
-					array($locale, $user['user_id'], $user['name']));
-			}
-		}
-	}
-
-	$groups_to_update_results = db_install_fetch_assoc('SELECT *
-		FROM settings_user_group
-		WHERE name="user_language"');
-	$groups_to_update = $groups_to_update_results['data'];
-
-	if (cacti_sizeof($groups_to_update)) {
-		foreach($groups_to_update as $group) {
-			if (strpos($group['value'], '-') === false) {
-				$locale = repair_locale($group['value']);
-
-				db_install_execute('UPDATE settings_user_group
-					SET value = ?
-					WHERE group_id = ?
-					AND name = ?',
-					array($locale, $group['group_id'], $group['name']));
-			}
-		}
-	}
+	db_install_drop_key('data_source_profiles_cf', 'index', 'data_source_profile_id');
+	db_install_drop_key('data_template_rrd', 'index', 'local_data_id');
+	db_install_drop_key('graph_template_input_defs', 'index', 'graph_template_input_id');
+	db_install_drop_key('host', 'index', 'site_id');
+	db_install_drop_key('host_snmp_query', 'index', 'host_id');
+	db_install_drop_key('host_template_graph', 'index', 'host_template_id');
+	db_install_drop_key('host_template_snmp_query', 'index', 'host_template_id');
+	db_install_drop_key('processes', 'index', 'pid');
+	db_install_drop_key('snmpagent_cache_notifications', 'index', 'name');
+	db_install_drop_key('snmpagent_cache_textual_conventions', 'index', 'name');
+	db_install_drop_key('snmpagent_managers_notifications', 'index', 'manager_id_notification');
+	db_install_drop_key('snmp_query_graph_rrd', 'index', 'snmp_query_graph_id');
 }
 
