@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -740,7 +740,15 @@ class spikekill {
 								$rra[$rra_num][$ds_num]['variance_avg'] = 'NAN';
 							} else {
 								$myds = $ds;
-								$myds = array_filter($myds, array($this, 'removeNanFromSamples'));
+
+								/* remove NaN entries from the data set */
+								if (cacti_sizeof($myds)) {
+									foreach($myds as $timestamp => $value) {
+										if (stripos($value, 'nan') !== false) {
+											unset($myds[$timestamp]);
+										}
+									}
+								}
 
 								/* remove high outliers */
 								rsort($myds, SORT_NUMERIC);
@@ -773,10 +781,6 @@ class spikekill {
 		}
 	}
 
-	private function removeNanFromSamples(&$string) {
-		return stripos($string, 'nan') === false;
-	}
-
 	private function calculateOverallStatistics(&$rra, &$samples) {
 		$rra_num = 0;
 		if (cacti_sizeof($rra)) {
