@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -72,16 +72,17 @@ if (!cacti_sizeof($page)) {
 		}
 
 		if (preg_match('/^((((ht|f)tp(s?))\:\/\/){1}\S+)/i', $page['contentfile'])) {
-			print '<iframe id="content" src="' . $page['contentfile'] . '" frameborder="0"></iframe>';
+			print '<iframe id="content" src="' . $page['contentfile'] . '" sandbox="allow-scripts allow-popups allow-forms" frameborder="0"></iframe>';
 		} else {
 			print '<div id="content">';
 
-			$file = $config['base_path'] . "/include/content/" . $page['contentfile'];
+			$basepath = $config['base_path'] . '/include/content';
+			$file     = realpath($basepath . '/' . $page['contentfile']);
 
-			if (file_exists($file)) {
-				include_once($file);
+			if ($file !== false && substr($file, 0, strlen($basepath)) == $basepath) {
+				print file_get_contents($file);
 			} else {
-				print '<h1>The file \'' . $page['contentfile'] . '\' does not exist!!</h1>';
+				print '<h1>The file \'' . html_escape($page['contentfile']) . '\' does not exist!!</h1>';
 			}
 
 			print '</div>';
